# Installation

The preferred installation is via pip(x), indifferent whether you are Windows, Linux or Mac:

```shell
pip install check_config
```

or

```shell
pipx install check_config
```

Alternatively you can use:

```shell
cargo install check_config
```
